==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMOOMSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class JVMOOMSpecBuilder extends JVMOOMSpecFluentImpl<JVMOOMSpecBuilder> implements VisitableBuilder<JVMOOMSpec,JVMOOMSpecBuilder> {

    JVMOOMSpecFluent<?> fluent;
    Boolean validationEnabled;

    public JVMOOMSpecBuilder() {
        this(true);
    }

    public JVMOOMSpecBuilder(Boolean validationEnabled) {
        this(new JVMOOMSpec(), validationEnabled);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new JVMOOMSpec(), validationEnabled);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent,JVMOOMSpec instance) {
        this(fluent, instance, true);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent,JVMOOMSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAfter(instance.getAfter()); 
        fluent.withArea(instance.getArea()); 
        fluent.withBlock(instance.getBlock()); 
        fluent.withClassname(instance.getClassname()); 
        fluent.withInterval(instance.getInterval()); 
        fluent.withMethodname(instance.getMethodname()); 
        fluent.withWildmode(instance.getWildmode()); 
        this.validationEnabled = validationEnabled; 
    }

    public JVMOOMSpecBuilder(JVMOOMSpec instance) {
        this(instance,true);
    }

    public JVMOOMSpecBuilder(JVMOOMSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAfter(instance.getAfter()); 
        this.withArea(instance.getArea()); 
        this.withBlock(instance.getBlock()); 
        this.withClassname(instance.getClassname()); 
        this.withInterval(instance.getInterval()); 
        this.withMethodname(instance.getMethodname()); 
        this.withWildmode(instance.getWildmode()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableJVMOOMSpec build() {
        EditableJVMOOMSpec buildable = new EditableJVMOOMSpec(fluent.isAfter(),fluent.getArea(),fluent.getBlock(),fluent.getClassname(),fluent.getInterval(),fluent.getMethodname(),fluent.isWildmode());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        JVMOOMSpecBuilder that = (JVMOOMSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMOOMSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class JVMOOMSpecBuilder extends JVMOOMSpecFluentImpl<JVMOOMSpecBuilder> implements VisitableBuilder<JVMOOMSpec,JVMOOMSpecBuilder> {

    JVMOOMSpecFluent<?> fluent;
    Boolean validationEnabled;

    public JVMOOMSpecBuilder() {
        this(true);
    }

    public JVMOOMSpecBuilder(Boolean validationEnabled) {
        this(new JVMOOMSpec(), validationEnabled);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new JVMOOMSpec(), validationEnabled);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent,JVMOOMSpec instance) {
        this(fluent, instance, true);
    }

    public JVMOOMSpecBuilder(JVMOOMSpecFluent<?> fluent,JVMOOMSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAfter(instance.getAfter()); 
        fluent.withArea(instance.getArea()); 
        fluent.withBlock(instance.getBlock()); 
        fluent.withClassname(instance.getClassname()); 
        fluent.withInterval(instance.getInterval()); 
        fluent.withMethodname(instance.getMethodname()); 
        fluent.withWildmode(instance.getWildmode()); 
        this.validationEnabled = validationEnabled; 
    }

    public JVMOOMSpecBuilder(JVMOOMSpec instance) {
        this(instance,true);
    }

    public JVMOOMSpecBuilder(JVMOOMSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAfter(instance.getAfter()); 
        this.withArea(instance.getArea()); 
        this.withBlock(instance.getBlock()); 
        this.withClassname(instance.getClassname()); 
        this.withInterval(instance.getInterval()); 
        this.withMethodname(instance.getMethodname()); 
        this.withWildmode(instance.getWildmode()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableJVMOOMSpec build() {
        EditableJVMOOMSpec buildable = new EditableJVMOOMSpec(fluent.getAfter(),fluent.getArea(),fluent.getBlock(),fluent.getClassname(),fluent.getInterval(),fluent.getMethodname(),fluent.getWildmode());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        JVMOOMSpecBuilder that = (JVMOOMSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
